package logger

import (
	"log"
	"os"

	"github.com/spf13/cobra"
	"github.com/volker-raschek/flucky/pkg/cli"
	"github.com/volker-raschek/flucky/pkg/config"
)

var quiet bool

var listLoggerCmd = &cobra.Command{
	Use:     "ls",
	Short:   "List internal Loggers",
	Aliases: []string{"list"},
	Example: "flucky logger ls",
	Run: func(cmd *cobra.Command, args []string) {

		// read configuration
		fc, err := config.Read(cfg)
		if err != nil {
			log.Fatalln(err)
		}

		// print all configured remote addresses on stdout
		cli.PrintLoggers(fc, os.Stdout)

		// save new configuration
		err = config.Write(fc, cfg)
		if err != nil {
			log.Fatalln(err)
		}
	},
}

func init() {
	loggerCmd.AddCommand(listLoggerCmd)
}
